@@ -15,13 +15,13 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 $VERSION = eval $VERSION;
 
 ## Load our modules
@@ -32,7 +32,6 @@ use Time::HiRes qw( gettimeofday );
 ## Handle importing/exporting of symbols
 
 use base qw( Exporter );
-our @ISA        = qw ( Exporter );
 our @EXPORT_OK  = qw ( getSNTPTime );
 
 =head1 SYNOPSIS
@@ -67,22 +66,6 @@ This module exports a single method (getSNTPTime) and returns
  further processing or manipulation according to the user needs.
  Maximum accuracy down to nano seconds can only be achieved on LinuxOS.
 
-=head2 EXPORT
-
-  my %hashInput = (
-      -hostname      => $hostname,    # hostnmae or IP
-      -port          => $port,        # default NTP port 123 
-      -RFC4330       => $RFC4330,     # default 0
-      -clearScreen   => $clearScreen, # default 0
-      );
-
-  my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
-
-This module exports a single method - getSNTPTime and an error
- string in case of an error or a faulty operation. It expects a
- hash as an input. The input can have four different hash
- keys (-hostname, port, RFC4330 and -clearScreen). 
-
 =over 4
 
 =item * HOSTNAME
@@ -133,83 +116,33 @@ use constant {
     DEFAULT_NTP_PORT => 123,
 };
 
+=head2 getSNTPTime
+
+  my %hashInput = (
+      -hostname      => $hostname,    # hostnmae or IP
+      -port          => $port,        # default NTP port 123 
+      -RFC4330       => $RFC4330,     # default 0
+      -clearScreen   => $clearScreen, # default 0
+      );
+
+  my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
+
+This module exports a single method - getSNTPTime and an error
+ string in case of an error or a faulty operation. It expects a
+ hash as an input. The input can have four different hash
+ keys (-hostname, port, RFC4330 and -clearScreen). 
+
+=cut
+
 sub getSNTPTime {
-
-    my $unpack_ip = sub {
-	my $ip;
-	my $stratum = shift;	
-	my $tmp_ip = shift;
-	if($stratum < 2){
-	    $ip = unpack("A4", 
-			 pack("H8", $tmp_ip)
-		);
-	}else{
-	    $ip = sprintf("%d.%d.%d.%d",
-			  unpack("C4",
-				 pack("H8", $tmp_ip)
-			  )
-		);
-	}
-	return $ip;
-    };
-
-    my $bin_2_dec = sub {
-	my $bits     = shift;
-	my $size     = shift;
-	my $template = shift;
-	return unpack($template, pack("B$size", substr("0" x $size . $bits , -$size)));
-    };
-
-    my $checkHashKeys = sub {
-	my @keysToCompare = ( "-hostname", "-port", "-RFC4330", "-clearScreen" );
-	my %hashInputToCompare = @_;
-	my @hashInputKeysToCompare = keys %hashInputToCompare;
-	
-	my @differendKeys = keyDifference(\@hashInputKeysToCompare, \@keysToCompare);
-	
-	if (@differendKeys) { return TRUE } else { return FALSE };
-	
-	sub keyDifference {
-	    my %hashdiff = map{ $_ => 1 } @{$_[1]}; 
-	    return grep { !defined $hashdiff{$_} }  @{$_[0]};
-	}
-    };
-
-    my $verify_port = sub {
-	my $port = shift;
-	return FALSE if (!defined $port);
-	if ( defined $port && $port =~ /^[0-9]+$/ ) {
-	    if ( $port >= MIN_UDP_PORT && MAX_UDP_PORT >= $port ) {
-		return FALSE;
-	    }
-	}
-	return TRUE;
-    };
-
-    my $verify_boolean = sub {
-	my $input = shift;
-	return FALSE if (!defined $input);
-	if ( defined $input && $input =~ /^[0-9]+$/ ) {
-	    if ( $input eq "0" or $input eq "1" ) {
-		return FALSE;
-	    }
-	}
-	return TRUE;
-    };
-
-    sub root_dispersion_process {
-	my $sub_dispersion = sprintf("%0.10f", $_[0]);
-	return $sub_dispersion =~ s/\..*$//;
-    }
-
     my $error = undef;
     my %moduleInput = @_;
 
-    return ($error = "Not defined key(s)", \%moduleInput) if ($checkHashKeys->(%moduleInput));
+    return ($error = "Not defined key(s)", \%moduleInput) if (_checkHashKeys(%moduleInput));
     return ($error = "Not defined Hostname", \%moduleInput) if (!$moduleInput{-hostname});
-    return ($error = "Not correct port number", \%moduleInput) if ($verify_port->($moduleInput{-port}));
-    return ($error = "Not correct RFC4330 input", \%moduleInput) if ($verify_boolean->($moduleInput{-RFC4330}));
-    return ($error = "Not correct clearScreen input", \%moduleInput) if ($verify_boolean->($moduleInput{-clearScreen}));
+    return ($error = "Not correct port number", \%moduleInput) if (_verifyPort($moduleInput{-port}));
+    return ($error = "Not correct RFC4330 input", \%moduleInput) if (_verifyBoolean($moduleInput{-RFC4330}));
+    return ($error = "Not correct clearScreen input", \%moduleInput) if (_verifyBoolean($moduleInput{-clearScreen}));
 
     my $client_socket;
     eval {
@@ -318,19 +251,19 @@ sub getSNTPTime {
     $Array_Hash_To_Receive[0]{"LI Binary"} = 
 	substr( $Array_Hash_To_Receive[0]{"LI VN Mode"} , 0 , 2 );
     $Array_Hash_To_Receive[0]{"LI"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[0]{"LI Binary"} , 8 , "c" );
+	_binaryToDecimal( $Array_Hash_To_Receive[0]{"LI Binary"} , 8 , "c" );
     delete $Array_Hash_To_Receive[0]{"LI Binary"};
 
     $Array_Hash_To_Receive[0]{"VN Binary"} = 
 	substr( $Array_Hash_To_Receive[0]{"LI VN Mode"} , 2 , 3 );
     $Array_Hash_To_Receive[0]{"VN"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[0]{"VN Binary"} , 8 , "c" );
+	_binaryToDecimal( $Array_Hash_To_Receive[0]{"VN Binary"} , 8 , "c" );
     delete $Array_Hash_To_Receive[0]{"LI Binary"};
 
     $Array_Hash_To_Receive[0]{"Mode Binary"} = 
 	substr( $Array_Hash_To_Receive[0]{"LI VN Mode"} , 5 , 3 );
     $Array_Hash_To_Receive[0]{"Mode"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[0]{"Mode Binary"} , 8 , "c" );
+	_binaryToDecimal( $Array_Hash_To_Receive[0]{"Mode Binary"} , 8 , "c" );
     delete $Array_Hash_To_Receive[0]{"Mode Binary"};
     delete $Array_Hash_To_Receive[0]{"LI VN Mode"};
 
@@ -345,27 +278,27 @@ sub getSNTPTime {
     }
 
     $Array_Hash_To_Receive[4]{"Root Delay"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[4]{"Root Delay"} , 16 , "s" );
+	_binaryToDecimal( $Array_Hash_To_Receive[4]{"Root Delay"} , 16 , "s" );
 
     # print "Root Delay Fraction Binary: " . $Array_Hash_To_Receive[5]{Root_Delay_Fraction} . "\n";
     $Array_Hash_To_Receive[5]{"Root Delay Fraction"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[5]{"Root Delay Fraction"} , 16 , "n" );
+	_binaryToDecimal( $Array_Hash_To_Receive[5]{"Root Delay Fraction"} , 16 , "n" );
     
     $Array_Hash_To_Receive[4]{"Root Delay"} = 
 	$Array_Hash_To_Receive[4]{"Root Delay"} . "." . $Array_Hash_To_Receive[5]{"Root Delay Fraction"};
 
     $Array_Hash_To_Receive[6]{"Root Dispersion"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[6]{"Root Dispersion"} , 16 , "n" );
+	_binaryToDecimal( $Array_Hash_To_Receive[6]{"Root Dispersion"} , 16 , "n" );
 
     # print "Root Dispersion Binary: " . $Array_Hash_To_Receive[7]{Root_Dispersion_Fraction} . "\n";
     $Array_Hash_To_Receive[7]{"Root Dispersion Fraction"} = 
-	$bin_2_dec->( $Array_Hash_To_Receive[7]{"Root Dispersion Fraction"} , 16 , "n" );
+	_binaryToDecimal( $Array_Hash_To_Receive[7]{"Root Dispersion Fraction"} , 16 , "n" );
     
     $Array_Hash_To_Receive[6]{"Root Dispersion"} = 
 	$Array_Hash_To_Receive[6]{"Root Dispersion"} . "." . $Array_Hash_To_Receive[7]{"Root Dispersion Fraction"};
     
     $Array_Hash_To_Receive[8]{"Reference Identifier"} = 
-	$unpack_ip->($Array_Hash_To_Receive[1]{"Stratum"},$Array_Hash_To_Receive[8]{"Reference Identifier"});
+	_unpackIP($Array_Hash_To_Receive[1]{"Stratum"},$Array_Hash_To_Receive[8]{"Reference Identifier"});
 
     $Array_Hash_To_Receive[9]{"Reference Timestamp Sec"} = 
 	$Array_Hash_To_Receive[9]{"Reference Timestamp Sec"} - UNIX_EPOCH;
@@ -494,6 +427,68 @@ sub getSNTPTime {
     return $error, \%moduleOutput;
 }
 
+sub _checkHashKeys {
+    my @keysToCompare = ( "-hostname", "-port", "-RFC4330", "-clearScreen" );
+    my %hashInputToCompare = @_;
+    my @hashInputKeysToCompare = keys %hashInputToCompare;
+    
+    my @differendKeys = _keyDifference(\@hashInputKeysToCompare, \@keysToCompare);
+    
+    if (@differendKeys) { return TRUE } else { return FALSE };
+};
+
+sub _keyDifference {
+    my %hashdiff = map{ $_ => 1 } @{$_[1]}; 
+    return grep { !defined $hashdiff{$_} }  @{$_[0]};
+}
+
+sub _verifyPort {
+    my $port = shift;
+    return FALSE if (!defined $port);
+    if ( defined $port && $port =~ /^[0-9]+$/ ) {
+	if ( $port >= MIN_UDP_PORT && MAX_UDP_PORT >= $port ) {
+	    return FALSE;
+	}
+    }
+    return TRUE;
+};
+
+sub _verifyBoolean {
+    my $input = shift;
+    return FALSE if (!defined $input);
+    if ( defined $input && $input =~ /^[0-9]+$/ ) {
+	if ( $input eq "0" or $input eq "1" ) {
+	    return FALSE;
+	}
+    }
+    return TRUE;
+};
+
+sub _unpackIP{
+    my $ip;
+    my $stratum = shift;	
+    my $tmp_ip = shift;
+    if($stratum < 2){
+	$ip = unpack("A4", 
+		     pack("H8", $tmp_ip)
+	    );
+    }else{
+	$ip = sprintf("%d.%d.%d.%d",
+		      unpack("C4",
+			     pack("H8", $tmp_ip)
+		      )
+	    );
+    }
+    return $ip;
+};
+
+sub _binaryToDecimal {
+    my $bits     = shift;
+    my $size     = shift;
+    my $template = shift;
+    return unpack($template, pack("B$size", substr("0" x $size . $bits , -$size)));
+};
+
 =head1 EXAMPLE
 
 This example gets the time from a remote NTP server from the
@@ -518,6 +513,7 @@ We use the L<Data::Dumper|http://search.cpan.org/~ilyam/Data-Dumper-2.121/Dumper
       -clearScreen   => 1,
       );
 
+
   my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
 
   print Dumper $hashRefOutput;
@@ -568,7 +564,7 @@ L<http://search.cpan.org/dist/Net-SNTP-Client/>
 
 =head1 SEE ALSO
 
-perl, IO::Socket, Net::NTP, RFC4330
+perl, IO::Socket, Net::NTP, Net::SNTP::Server, RFC4330
 
 Net::NTP has a similar focus as this module. In my opinion it
  is less accurate when it comes to the precission bellow second(s).
@@ -581,6 +577,13 @@ Based on the current known modules Net::SNTP::Client is only similar
 
 Be aware that on different OS different precision can be achieved.
 
+=head1 DIFFERENCES BETWEEN NTP AND SNTP
+
+SNTP (Simple Network Time Protocol) and NTP (Network Time Protocol)
+ are describing exactly the same network package format, the differences
+ can be found in the way how a system deals with the content of these
+ packages in order to synchronize its time.
+
 =head1 ACKNOWLEDGEMENTS
 
 The original concept for this module was based on F<NTP.pm>
@@ -634,9 +637,10 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 11.0  2015/07/25 01:09:31 am  Thanos
+Revision 12.0  2015/07/25 12:10:31 pm  Thanos
 
 
 =cut
 
 1; # End of Net::SNTP::Client
+
